@@ -10,9 +10,11 @@ def simple_urljoin(*parts, append_slash=False):
     paths = [x for x in paths if x]
     if scheme and not netloc and paths:
         netloc, *paths = paths
-    path = '/'.join((x.strip('/') for x in paths))
-    append_slash = append_slash or (paths and parts[-1].endswith('/'))
-    if append_slash:
+    path = '/'.join((x.strip('/') for x in paths if x.strip('/')))
+
+    if paths and parts[0].startswith('/'):
+        path = '/' + path
+    if append_slash or (paths and parts[-1].endswith('/')):
         path += '/'
     query = _last(queries)
     fragment = _last(fragments)
